mchammer.Result
===============

.. currentmodule:: mchammer

.. autoclass:: Result
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Result.add_step_result
      ~Result.get_final_position_matrix
      ~Result.get_log
      ~Result.get_number_passed
      ~Result.get_step_count
      ~Result.get_steps_properties
      ~Result.get_timing
      ~Result.get_trajectory
      ~Result.update_log
   
   

   
   
   